@@ -20,7 +20,7 @@
 
 enum got_diff_output_format {
 	GOT_DIFF_OUTPUT_UNIDIFF,
-	GOT_DIFF_OUTPUT_EDSCRIPT,
+	GOT_DIFF_OUTPUT_PLAIN,
 };
 
 struct got_diffreg_result {
@@ -41,17 +41,13 @@ struct got_diffreg_result {
 const struct got_error *got_diff_get_config(struct diff_config **,
     enum got_diff_algorithm, diff_atomize_func_t, void *);
 const struct got_error *got_diff_prepare_file(FILE *, char **, size_t *,
-    struct diff_data *, const struct diff_config *, int, int); 
+    struct diff_data *, const struct diff_config *, int, int);
 const struct got_error *got_diffreg(struct got_diffreg_result **, FILE *,
     FILE *, enum got_diff_algorithm, int, int);
-const struct got_error *got_diffreg_output(off_t **, size_t *,
+const struct got_error *got_diffreg_output(struct got_diff_line **, size_t *,
     struct got_diffreg_result *, int, int, const char *, const char *,
     enum got_diff_output_format, int, FILE *);
 const struct got_error *got_diffreg_result_free(struct got_diffreg_result *);
-const struct got_error *got_diffreg_result_free_left(
-    struct got_diffreg_result *);
-const struct got_error *got_diffreg_result_free_right(
-    struct got_diffreg_result *);
 const struct got_error *got_diffreg_close(char *, size_t, char *, size_t);
 
 const struct got_error *got_merge_diff3(int *, int, FILE *, FILE *, FILE *,
